Getting Started
!!!!!!!!!!!!!!!

This section describes installation and setup for AnyVar.

* :doc:`Quick Start (Docker Compose) <docker_compose>`: Use the provided Docker Compose file to quickly launch AnyVar REST service without any additional resource acquisition or configuration. Ideal for users who only need to interact with AnyVar via HTTP.
* :doc:`Manual Setup <manual_setup>`: Individually install AnyVar and other data and resource dependencies in a local environment. Preferable for users seeking to import the AnyVar Python library directly, e.g. in custom scripts or Jupyter notebooks.

.. toctree::
    :maxdepth: 2
    :hidden:

    Quick Start: Docker Compose <docker_compose>
    Manual Setup<manual_setup>
